"""Red Hat logo"""

from archey.colors import Colors

COLORS = [Colors.RED_BRIGHT, Colors.WHITE_BRIGHT, Colors.RED_NORMAL]

LOGO = [
    """{c[0]}              {c[2]}\\`.-..........\\`{c[0]}            """,
    """{c[0]}             {c[2]}\\`////////::.\\`-/.{c[0]}           """,
    """{c[0]}             {c[2]}-: ....-////////.{c[0]}            """,
    """{c[0]}             {c[2]}//:-::///////////\\`{c[0]}          """,
    """{c[0]}      {c[2]}\\`--::: \\`-://////////////:{c[0]}         """,
    """{c[0]}      {c[2]}//////-    \\`\\`.-://///////{c[0]} .\\`     """,
    """{c[0]}      {c[2]}\\`://////:-.\\`    :///////::///:\\`{c[0]}  """,
    """{c[0]}        {c[2]}.-/////////:---/////////////:{c[0]}     """,
    """{c[0]}           {c[2]}.-://////////////////////.{c[0]}     """,
    """{c[0]}          {c[1]}yMN+\\`.-${c[2]}::///////////////-\\`{c[0]}   """,
    """{c[0]}       {c[1]}.-\\`:NMMNMs\\`  \\`..-------..\\`{c[0]}     """,
    """{c[0]}        {c[1]}MN+/mMMMMMhoooyysshsss{c[0]}            """,
    """{c[0]} {c[1]}MMM    MMMMMMMMMMMMMMyyddMMM+{c[0]}            """,
    """{c[0]}  {c[1]}MMMM   MMMMMMMMMMMMMNdyNMMh\\`     hyhMMM{c[0]}""",
    """{c[0]}   {c[1]}MMMMMMMMMMMMMMMMyoNNNMMM+.   MMMMMMMM{c[0]}  """,
    """{c[0]}    {c[1]}MMNMMMNNMMMMMNM+ mhsMNyyyyMNMMMMsMM{c[0]}   """,
]
